@@ -33,5 +33,8 @@ class FrameConstraint(Constraint):
         normal = self.geometry.zaxis
         self._normal = Vector(* vector_component(self.residual, normal))
 
+    def update(self, damping=0.1):
+        self._location = self.location + self.tangent * damping
+
     def project(self):
         pass
